@@ -127,7 +127,9 @@ class LibvirtDriver(AbstractSystemsDriver):
     DEFAULT_BIOS_ATTRIBUTES = {"BootMode": "Uefi",
                                "EmbeddedSata": "Raid",
                                "NicBoot1": "NetworkBoot",
-                               "ProcTurboMode": "Enabled"}
+                               "ProcTurboMode": "Enabled",
+                               "SecureBootStatus": "Enabled",
+                               "SerialNumber": "QPX12345"}
 
     STORAGE_POOL = 'default'
 
@@ -951,7 +953,7 @@ class LibvirtDriver(AbstractSystemsDriver):
             elif lv_device == 'floppy':
                 tgt_dev, tgt_bus = ('fda', 'fdc')
             else:
-                tgt_dev, tgt_bus = ('sdc', controller_type)
+                tgt_dev, tgt_bus = ('sdx', controller_type)
 
             # Enumerate existing disks to find a free unit on the bus
 
